@@ -1,15 +1,19 @@
 
 #' Random walk on a graph
 #'
-#' \code{random_walk} performs a random walk on the graph and returns the
-#' vertices that the random walk passed through. \code{random_edge_walk}
+#' `random_walk()` performs a random walk on the graph and returns the
+#' vertices that the random walk passed through. `random_edge_walk()`
 #' is the same but returns the edges that that random walk passed through.
 #'
 #' Do a random walk. From the given start vertex, take the given number of
 #' steps, choosing an edge from the actual vertex uniformly randomly. Edge
-#' directions are observed in directed graphs (see the \code{mode} argument
+#' directions are observed in directed graphs (see the `mode` argument
 #' as well). Multiple and loop edges are also observed.
 #'
+#' For igraph < 1.6.0, `random_walk()` counted steps differently,
+#' and returned a sequence of length `steps` instead of `steps + 1`.
+#' This has changed to improve consistency with the underlying C library.
+#'
 #' @param graph The input graph, might be undirected or directed.
 #' @param start The start vertex.
 #' @param steps The number of steps to make.
@@ -17,16 +21,18 @@
 #'   probability that an edge is selected by the random walker. In other
 #'   words, larger edge weights correspond to stronger connections. The
 #'   \sQuote{weight} edge attribute is used if present. Supply
-#'   \sQuote{\code{NA}} here if you want to ignore the \sQuote{weight} edge
+#'   \sQuote{`NA`} here if you want to ignore the \sQuote{weight} edge
 #'   attribute.
-#' @param mode How to follow directed edges. \code{"out"} steps along the
-#'   edge direction, \code{"in"} is opposite to that. \code{"all"} ignores
+#' @param mode How to follow directed edges. `"out"` steps along the
+#'   edge direction, `"in"` is opposite to that. `"all"` ignores
 #'   edge directions. This argument is ignored for undirected graphs.
-#' @param stuck What to do if the random walk gets stuck. \code{"return"}
-#'   returns the partial walk, \code{"error"} raises an error.
-#' @return For \code{random_walk}, a vertex sequence containing the vertices
-#'   along the walk. For \code{random_edge_walk}, an edge sequence containing
+#' @param stuck What to do if the random walk gets stuck. `"return"`
+#'   returns the partial walk, `"error"` raises an error.
+#' @return For `random_walk()`, a vertex sequence of length `steps + 1`
+#'   containing the vertices along the walk, starting with `start`.
+#'   For `random_edge_walk()`, an edge sequence of length `steps` containing
 #'   the edges along the walk.
+#' @family random_walk
 #' @export
 #' @examples
 #' ## Stationary distribution of a Markov chain
@@ -42,7 +48,15 @@
 #'
 #' ## But these are (almost) the same
 #' cor(table(w), pg)
-random_walk <- random_walk
+random_walk <- function(
+    graph,
+    start,
+    steps,
+    mode = c("out", "in", "all", "total"),
+    stuck = c("return", "error")) {
+  random_walk_impl(graph, start, steps + 1, mode, stuck)
+}
 
 #' @rdname random_walk
-random_edge_walk <- random_edge_walk
+#' @export
+random_edge_walk <- random_edge_walk_impl
