@@ -29,6 +29,7 @@
 #include "igraph_interface.h"
 #include "igraph_iterators.h"
 #include "igraph_memory.h"
+#include "igraph_random.h"
 #include "igraph_statusbar.h"
 #include "igraph_structural.h"
 
@@ -152,72 +153,6 @@ static int igraph_i_community_leading_eigenvector(igraph_real_t *to,
     return 0;
 }
 
-static int igraph_i_community_leading_eigenvector2(igraph_real_t *to,
-                                                   const igraph_real_t *from,
-                                                   int n, void *extra) {
-
-    igraph_i_community_leading_eigenvector_data_t *data = extra;
-    long int j, k, nlen, size = n;
-    igraph_vector_t *idx = data->idx;
-    igraph_vector_t *idx2 = data->idx2;
-    igraph_vector_t *tmp = data->tmp;
-    igraph_adjlist_t *adjlist = data->adjlist;
-    igraph_real_t ktx, ktx2;
-    long int no_of_edges = data->no_of_edges;
-    igraph_vector_t *mymembership = data->mymembership;
-    long int comm = data->comm;
-
-    /* Ax */
-    for (j = 0; j < size; j++) {
-        long int oldid = (long int) VECTOR(*idx)[j];
-        igraph_vector_int_t *neis = igraph_adjlist_get(adjlist, oldid);
-        nlen = igraph_vector_int_size(neis);
-        to[j] = 0.0;
-        VECTOR(*tmp)[j] = 0.0;
-        for (k = 0; k < nlen; k++) {
-            long int nei = (long int) VECTOR(*neis)[k];
-            long int neimemb = (long int) VECTOR(*mymembership)[nei];
-            if (neimemb == comm) {
-                long int fi = (long int) VECTOR(*idx2)[nei];
-                if (fi < size) {
-                    to[j] += from[fi];
-                }
-                VECTOR(*tmp)[j] += 1;
-            }
-        }
-    }
-
-    /* Now calculate k^Tx/2m */
-    ktx = 0.0; ktx2 = 0.0;
-    for (j = 0; j < size + 1; j++) {
-        long int oldid = (long int) VECTOR(*idx)[j];
-        igraph_vector_int_t *neis = igraph_adjlist_get(adjlist, oldid);
-        long int degree = igraph_vector_int_size(neis);
-        if (j < size) {
-            ktx += from[j] * degree;
-        }
-        ktx2 += degree;
-    }
-    ktx = ktx / no_of_edges / 2.0;
-    ktx2 = ktx2 / no_of_edges / 2.0;
-
-    /* Now calculate Bx */
-    for (j = 0; j < size; j++) {
-        long int oldid = (long int) VECTOR(*idx)[j];
-        igraph_vector_int_t *neis = igraph_adjlist_get(adjlist, oldid);
-        igraph_real_t degree = igraph_vector_int_size(neis);
-        to[j] = to[j] - ktx * degree;
-        VECTOR(*tmp)[j] = VECTOR(*tmp)[j] - ktx2 * degree;
-    }
-
-    /* -d_ij summa l in G B_il */
-    for (j = 0; j < size; j++) {
-        to[j] -= VECTOR(*tmp)[j] * from[j];
-    }
-
-    return 0;
-}
-
 static int igraph_i_community_leading_eigenvector_weighted(igraph_real_t *to,
                                                            const igraph_real_t *from,
                                                            int n, void *extra) {
@@ -282,82 +217,13 @@ static int igraph_i_community_leading_eigenvector_weighted(igraph_real_t *to,
     return 0;
 }
 
-static int igraph_i_community_leading_eigenvector2_weighted(igraph_real_t *to,
-                                                            const igraph_real_t *from,
-                                                            int n, void *extra) {
-
-    igraph_i_community_leading_eigenvector_data_t *data = extra;
-    long int j, k, nlen, size = n;
-    igraph_vector_t *idx = data->idx;
-    igraph_vector_t *idx2 = data->idx2;
-    igraph_vector_t *tmp = data->tmp;
-    igraph_inclist_t *inclist = data->inclist;
-    igraph_real_t ktx, ktx2;
-    igraph_vector_t *mymembership = data->mymembership;
-    long int comm = data->comm;
-    const igraph_vector_t *weights = data->weights;
-    const igraph_t *graph = data->graph;
-    igraph_vector_t *strength = data->strength;
-    igraph_real_t sw = data->sumweights;
-
-    /* Ax */
-    for (j = 0; j < size; j++) {
-        long int oldid = (long int) VECTOR(*idx)[j];
-        igraph_vector_int_t *inc = igraph_inclist_get(inclist, oldid);
-        nlen = igraph_vector_int_size(inc);
-        to[j] = 0.0;
-        VECTOR(*tmp)[j] = 0.0;
-        for (k = 0; k < nlen; k++) {
-            long int edge = (long int) VECTOR(*inc)[k];
-            igraph_real_t w = VECTOR(*weights)[edge];
-            long int nei = IGRAPH_OTHER(graph, edge, oldid);
-            long int neimemb = (long int) VECTOR(*mymembership)[nei];
-            if (neimemb == comm) {
-                long int fi = (long int) VECTOR(*idx2)[nei];
-                if (fi < size) {
-                    to[j] += from[fi] * w;
-                }
-                VECTOR(*tmp)[j] += w;
-            }
-        }
-    }
-
-    /* k^Tx/2m */
-    ktx = 0.0; ktx2 = 0.0;
-    for (j = 0; j < size + 1; j++) {
-        long int oldid = (long int) VECTOR(*idx)[j];
-        igraph_real_t str = VECTOR(*strength)[oldid];
-        if (j < size) {
-            ktx += from[j] * str;
-        }
-        ktx2 += str;
-    }
-    ktx = ktx / sw / 2.0;
-    ktx2 = ktx2 / sw / 2.0;
-
-    /* Bx */
-    for (j = 0; j < size; j++) {
-        long int oldid = (long int) VECTOR(*idx)[j];
-        igraph_real_t str = VECTOR(*strength)[oldid];
-        to[j] = to[j] - ktx * str;
-        VECTOR(*tmp)[j] = VECTOR(*tmp)[j] - ktx2 * str;
-    }
-
-    /* -d_ij summa l in G B_il */
-    for (j = 0; j < size; j++) {
-        to[j] -= VECTOR(*tmp)[j] * from[j];
-    }
-
-    return 0;
-}
-
 static void igraph_i_levc_free(igraph_vector_ptr_t *ptr) {
     long int i, n = igraph_vector_ptr_size(ptr);
     for (i = 0; i < n; i++) {
         igraph_vector_t *v = VECTOR(*ptr)[i];
         if (v) {
             igraph_vector_destroy(v);
-            igraph_free(v);
+            IGRAPH_FREE(VECTOR(*ptr)[i]);
         }
     }
 }
@@ -490,6 +356,7 @@ int igraph_community_leading_eigenvector(const igraph_t *graph,
     igraph_dqueue_t tosplit;
     igraph_vector_t idx, idx2, mymerges;
     igraph_vector_t strength, tmp;
+    igraph_vector_t start_vec;
     long int staken = 0;
     igraph_adjlist_t adjlist;
     igraph_inclist_t inclist;
@@ -502,9 +369,6 @@ int igraph_community_leading_eigenvector(const igraph_t *graph,
     igraph_arpack_function_t *arpcb1 =
         weights ? igraph_i_community_leading_eigenvector_weighted :
         igraph_i_community_leading_eigenvector;
-    igraph_arpack_function_t *arpcb2 =
-        weights ? igraph_i_community_leading_eigenvector2_weighted :
-        igraph_i_community_leading_eigenvector2;
     igraph_real_t sumweights = 0.0;
 
     if (weights && no_of_edges != igraph_vector_size(weights)) {
@@ -628,7 +492,6 @@ int igraph_community_leading_eigenvector(const igraph_t *graph,
     }
 
     options->ncv = 0;   /* 0 means "automatic" in igraph_arpack_rssolve */
-    options->start = 0;
     options->which[0] = 'L'; options->which[1] = 'A';
 
     /* Memory for ARPACK */
@@ -653,7 +516,6 @@ int igraph_community_leading_eigenvector(const igraph_t *graph,
         long int comm = (long int) igraph_dqueue_pop_back(&tosplit);
         /* depth first search */
         long int size = 0;
-        igraph_real_t tmpev;
 
         IGRAPH_STATUSF(("Trying to split community %li... ", 0, comm));
         IGRAPH_ALLOW_INTERRUPTION();
@@ -670,16 +532,7 @@ int igraph_community_leading_eigenvector(const igraph_t *graph,
             continue;
         }
 
-        /* We solve two eigenproblems, one for the original modularity
-           matrix, and one for the modularity matrix after deleting the
-           last row and last column from it. This is a trick to find
-           multiple leading eigenvalues, because ARPACK is sometimes
-           unstable when the first two eigenvalues are requested, but it
-           does much better for the single principal eigenvalue. */
-
-        /* We start with the smaller eigenproblem. */
-
-        options->n = (int) size - 1;
+        options->n = (int) size;
         options->info = 0;
         options->nev = 1;
         options->ldv = 0;
@@ -688,62 +541,24 @@ int igraph_community_leading_eigenvector(const igraph_t *graph,
         options->lworkl = 0;        /* we surely have enough space */
         extra.comm = comm;
 
-        /* We try calling the solver twice, once from a random starting
-           point, once from a fixed one. This is because for some hard
-           cases it tends to fail. We need to suppress error handling for
-           the first call. */
-        {
-            int i;
-            int retval;
-            igraph_error_handler_t *errh =
-                igraph_set_error_handler(igraph_i_error_handler_none);
-            igraph_warning_handler_t *warnh =
-                igraph_set_warning_handler(igraph_warning_handler_ignore);
-            retval = igraph_arpack_rssolve(arpcb2, &extra, options, &storage, /*values=*/ 0, /*vectors=*/ 0);
-            igraph_set_error_handler(errh);
-            igraph_set_warning_handler(warnh);
-            if (retval != IGRAPH_SUCCESS && retval != IGRAPH_ARPACK_MAXIT && retval != IGRAPH_ARPACK_NOSHIFT) {
-                IGRAPH_ERROR("ARPACK call failed", retval);
-            }
-            if (options->nconv < 1) {
-                /* Call again from a fixed starting point. Note that we cannot use a
-                 * fixed all-1 starting vector as sometimes ARPACK would return a
-                 * 'starting vector is zero' error -- this is of course not true but
-                 * it's a result of ARPACK >= 3.6.3 trying to force the starting vector
-                 * into the range of OP (i.e. the matrix being solved). The initial
-                 * vector we use here seems to work, but I have no theoretical argument
-                 * for its usage; it just happens to work. */
-                options->start = 1;
-                options->info = 0;
-                options->ncv = 0;
-                options->lworkl = 0;    /* we surely have enough space */
-                for (i = 0; i < options->n ; i++) {
-                    storage.resid[i] = i % 2 ? 1 : -1;
-                }
-                IGRAPH_CHECK(igraph_arpack_rssolve(arpcb2, &extra, options, &storage,
-                                                   /*values=*/ 0, /*vectors=*/ 0));
-                options->start = 0;
-            }
+        /* Use a random start vector, but don't let ARPACK generate the
+         * start vector -- we want to use our own RNG. Also, we want to generate
+         * values close to +1 and -1 as this is what the eigenvector should
+         * look like if there _is_ some kind of a community structure at this
+         * step to discover. Experiments showed that shuffling a vector
+         * containing equal number of slightly perturbed +/-1 values yields
+         * convergence in most cases. */
+        options->start = 1;
+        options->mxiter = options->mxiter > 10000 ? options->mxiter : 10000;  /* use more iterations, we've had convergence problems with 3000 */
+        RNG_BEGIN();
+        for (i = 0; i < options->n; i++) {
+            storage.resid[i] = (i % 2 ? 1 : -1) + RNG_UNIF(-0.1, 0.1);
         }
-
-        if (options->nconv < 1) {
-            IGRAPH_ERROR("ARPACK did not converge", IGRAPH_ARPACK_FAILED);
-        }
-
-        tmpev = storage.d[0];
-
-        /* Now we do the original eigenproblem, again, twice if needed */
-
-        options->n = (int) size;
-        options->info = 0;
-        options->nev = 1;
-        options->ldv = 0;
-        options->nconv = 0;
-        options->lworkl = 0;    /* we surely have enough space */
-        options->ncv = 0;   /* 0 means "automatic" in igraph_arpack_rssolve */
+        RNG_END();
+        igraph_vector_view(&start_vec, storage.resid, options->n);
+        IGRAPH_CHECK(igraph_vector_shuffle(&start_vec));
 
         {
-            int i;
             int retval;
             igraph_error_handler_t *errh =
                 igraph_set_error_handler(igraph_i_error_handler_none);
@@ -752,27 +567,13 @@ int igraph_community_leading_eigenvector(const igraph_t *graph,
             if (retval != IGRAPH_SUCCESS && retval != IGRAPH_ARPACK_MAXIT && retval != IGRAPH_ARPACK_NOSHIFT) {
                 IGRAPH_ERROR("ARPACK call failed", retval);
             }
-            if (options->nconv < 1) {
-                /* Call again from a fixed starting point. See the comment a few lines
-                 * above about the exact choice of this starting vector */
-                options->start = 1;
-                options->info = 0;
-                options->ncv = 0;
-                options->lworkl = 0;    /* we surely have enough space */
-                for (i = 0; i < options->n; i++) {
-                    storage.resid[i] = i % 2 ? 1 : -1;
-                }
-                IGRAPH_CHECK(igraph_arpack_rssolve(arpcb1, &extra, options, &storage,
-                                                   /*values=*/ 0, /*vectors=*/ 0));
-                options->start = 0;
-            }
         }
 
         if (options->nconv < 1) {
             IGRAPH_ERROR("ARPACK did not converge", IGRAPH_ARPACK_FAILED);
         }
 
-        /* Ok, we have the leading eigenvector of the modularity matrix*/
+        /* Ok, we have the leading eigenvector of the modularity matrix */
 
         /* ---------------------------------------------------------------*/
         /* To avoid numeric errors */
@@ -843,18 +644,6 @@ int igraph_community_leading_eigenvector(const igraph_t *graph,
             continue;
         }
 
-        /* Check for multiple leading eigenvalues */
-
-        if (fabs(storage.d[0] - tmpev) < 1e-8) {
-            IGRAPH_STATUS("multiple principal eigenvalue, no split.\n", 0);
-            if (history) {
-                IGRAPH_CHECK(igraph_vector_push_back(history,
-                                                     IGRAPH_LEVC_HIST_FAILED));
-                IGRAPH_CHECK(igraph_vector_push_back(history, comm));
-            }
-            continue;
-        }
-
         /* Count the number of vertices in each community after the split */
         l = 0;
         for (j = 0; j < size; j++) {
