@@ -494,7 +494,7 @@ void igraph_decompose_destroy(igraph_vector_ptr_t *complist) {
     for (i = 0; i < igraph_vector_ptr_size(complist); i++) {
         if (VECTOR(*complist)[i] != 0) {
             igraph_destroy(VECTOR(*complist)[i]);
-            igraph_free(VECTOR(*complist)[i]);
+            IGRAPH_FREE(VECTOR(*complist)[i]);
         }
     }
 }
@@ -681,7 +681,6 @@ static int igraph_i_decompose_strong(const igraph_t *graph,
     igraph_dqueue_t q = IGRAPH_DQUEUE_NULL;
 
     long int no_of_clusters = 0;
-    long int act_cluster_size;
 
     igraph_vector_t out = IGRAPH_VECTOR_NULL;
     const igraph_vector_int_t* tmp;
@@ -805,7 +804,6 @@ static int igraph_i_decompose_strong(const igraph_t *graph,
 
         /* this node is gone for any future components */
         VECTOR(next_nei)[grandfather] = 1;
-        act_cluster_size = 1;
 
         /* add to component */
         IGRAPH_CHECK(igraph_vector_push_back(&verts, grandfather));
@@ -831,7 +829,6 @@ static int igraph_i_decompose_strong(const igraph_t *graph,
                 }
                 IGRAPH_CHECK(igraph_dqueue_push(&q, neighbor));
                 VECTOR(next_nei)[neighbor] = 1;
-                act_cluster_size++;
 
                 /* add to component */
                 IGRAPH_CHECK(igraph_vector_push_back(&verts, neighbor));
